# Fluxion

Fluxion is a python Coloring library and is very simple to use

this library will be updated in the future


# Install
```bash
pip install Fluxion
```

# Examples

```py
from Fluxion import Colors

print(f"{Colors.Blue}Hello World!")
#will print out hello world in blue.
```

## How it Looks like: 
## Screenshots

![App Screenshot](https://media.discordapp.net/attachments/998676329920741447/1096037920202309692/image.png?width=1181&height=372)